@@ -4,12 +4,48 @@ kombu.serialization
 
 Serialization utilities.
 
-:copyright: (c) 2009 - 2010
+:copyright: (c) 2009 - 2011 by Ask Solem
 :license: BSD, see LICENSE for more details.
 
 """
-
 import codecs
+import sys
+
+import pickle as pypickle
+try:
+    import cPickle as cpickle
+except ImportError:
+    cpickle = None  # noqa
+
+
+if sys.platform.startswith("java"):
+
+    def _decode(t, coding):
+        return codecs.getdecoder(coding)(t)[0]
+
+else:
+    _decode = codecs.decode
+
+if sys.version_info < (2, 6):  # pragma: no cover
+    # cPickle is broken in Python <= 2.5.
+    # It unsafely and incorrectly uses relative instead of absolute
+    # imports,
+    # so e.g.:
+    #       exceptions.KeyError
+    # becomes:
+    #       kombu.exceptions.KeyError
+    #
+    # Your best choice is to upgrade to Python 2.6,
+    # as while the pure pickle version has worse performance,
+    # it is the only safe option for older Python versions.
+    pickle = pypickle
+else:
+    pickle = cpickle or pypickle
+
+
+bytes_type = str
+if sys.version_info >= (3, 0):
+    bytes_type = bytes
 
 
 class SerializerNotInstalled(StandardError):
@@ -62,7 +98,7 @@ class SerializerRegistry(object):
         # If a raw string was sent, assume binary encoding
         # (it's likely either ASCII or a raw binary file, but 'binary'
         # charset will encompass both, even if not ideal.
-        if not serializer and isinstance(data, str):
+        if not serializer and isinstance(data, bytes_type):
             # In Python 3+, this would be "bytes"; allow binary data to be
             # sent as a message without getting encoder errors
             return "application/data", "binary", data
@@ -90,7 +126,7 @@ class SerializerRegistry(object):
         # Don't decode 8-bit strings or unicode objects
         if content_encoding not in ('binary', 'ascii-8bit') and \
                 not isinstance(data, unicode):
-            data = codecs.decode(data, content_encoding)
+            data = _decode(data, content_encoding)
 
         try:
             decoder = self._decoders[content_type]
@@ -234,8 +270,7 @@ def register_yaml():
 def register_pickle():
     """The fastest serialization method, but restricts
     you to python clients."""
-    import cPickle
-    registry.register('pickle', cPickle.dumps, cPickle.loads,
+    registry.register('pickle', pickle.dumps, pickle.loads,
                       content_type='application/x-python-serialize',
                       content_encoding='binary')
 
